function setup()

% Setup function for the Delta-Sigma Modulator
%
% Syntax:
%   "setup"
%
% Description:
%   "setup" sets various model and verification parameters.
%   Parameters are set as variables in the Matlab base workspace and specified in the model using the
%   variable names.
%
% See Also:
%   global_var,bounce_param

% declare global variables in base work space
evalin('base','global_var');

% declare global variables here
global_var


%Note:  changing params here means that they must be changed in the vct_sys file as well.
a = [0.0440 0.2881 0.7997];
b = [0.0440 0.2881 0.7997 1.0000];
c = [1 1 1];
g = 0;

% zero_threshold
assignin('base','zero_threshold',linearcon([],[], [0 0 -1] , [0]));

% overload
assignin('base','overload',linearcon([],[], [0 0 1 ; 0 0 -1] , [2 ; 2]));

% ICS - initial continuous set - both good and bad cases

% BAD CASE
% Use with "constant_in = 0.8" in the DelSig_sys.m file 
assignin('base','DelSig_ICS',{linearcon([],[],[ eye(3) ; -eye(3) ],[0.02;-0.01; 1.4 ; 0 ; 0.03;  -1.0])}); % BAD CASE 

% GOOD CASE
% Use with "constant_in = 0.6" in the DelSig_sys.m file
% assignin('base','DelSig_ICS',{linearcon([],[],[ eye(3) ; -eye(3) ],[0.01;0; 0.82 ; 0 ; 0.01; -0.8])}); % GOOD CASE

% Analysis Region
assignin('base','DelSig_AR',linearcon([],[],[ eye(3) ; -eye(3) ],[ 100 ; 100 ; 100; 100 ; 100 ; 100]));

% setup verification parameters
 GLOBAL_SYSTEM = 'DelSig';
 GLOBAL_APARAM = 'DelSig_param';

 return
