function f = stretch_func_lin(t,A,Ainv,b,n_vector,X0)

% Compute objective function for the outer-loop optimization problem in the
% flow pipe segment approximation procedure for `linear` (affine) dynamics.
%
% Syntax:
%   "f = stretch_fun_lin(t,A,Ainv,b,n_vector,X0)"
%
% Description:
%   Compute the following objective function value for the given "t"
%
%
%
%   "f(t) = { max (xt in Rt)  n_vector'*xt }"
%
%
%
%   where "n_vector" is a normal vector and "Rt" is the polytope
%   representing the reachable set under the continuous dynamics "dx/dt =
%   A*x + b" from the polytope "X0" at time "t". See help on
%   "seg_approx_lin.m" for more detail.
%
% Implementation:
%   The objective function for the optimization is a function of "t"
%   only. "A", "Ainv", "b","n_vector", and "X0" are optional parameters.
%   See MATLAB help on "fmincon.m" for more detail.
%
% See Also:
%   seg_approx_lin,linearcon,transform,step_response
%
% Revised by OS on 02/22/02

global GLOBAL_OPTIM_PAR

displacement = step_response(A,Ainv,b,t);
Xt = transform(X0,expm(A*t),displacement);
[CE,dE,CI,dI] = linearcon_data(Xt);
%Vt = vertices(Xt);

xt = linprog(-n_vector,CI,dI,CE,dE,[],[],[],GLOBAL_OPTIM_PAR);

% Changed by OS: If the number of vertices in R(t) is small, it should be quicker to find
% max (xt in Rt)  n_vector'*xt by using 'max' (resp. 'min')  instead of 'lp'

% xtn = min(-n_vector*Vt(1:length(Vt)));
f = -n_vector*xt;
