function display(v)

% Command window display of a vertices object
%
% Syntax:
%   "vtcs"
%
%   "display(vtcs)"
%
% Description:
%   "display(vtcs)" is called whenever a vertices object needs to be
%   displayed in the Matlab command window.
%
% Examples:
%
%
%
%   "a = ["
%
%   "2 2 4 4"
%
%   "1 3 3 1"
%
%   "0 0 0 0];"
%
%   "vtcs = vertices(a)"
%
%
%
%   returns
%
%
%
%   "vtcs:"
%
%   "v1 = [2.000000 1.000000 0.000000 ]^T"
%
%   "v2 = [2.000000 3.000000 0.000000 ]^T"
%
%   "v3 = [4.000000 3.000000 0.000000 ]^T"
%
%   "v4 = [4.000000 1.000000 0.000000 ]^T"
%
%
%
% See Also:
%   vertices


fprintf(1,['\n' inputname(1) ': '])
if isempty(v.list) 
  fprintf(1,' empty\n')
else
  fprintf(1,'\n')
  for k = 1:size(v.list,2)
    fprintf(1,'v%d = [',k)
    fprintf(1,'%f ',v.list(:,k))
    fprintf(1,']^T\n')
  end
end
fprintf(1,'\n')
